]> Shamusworld >> Repos - rmac/blobdiff - token.h
Added floating point support to expression evaluator, introduced FLOAT token, fixup...
[rmac] / token.h
diff --git a/token.h b/token.h
index 65b5b831a7dc1d5c126d28c8c7198009a0814dd4..cedaa037d8ce6752fd7d80133a33fac34a5cf5e6 100644 (file)
--- a/token.h
+++ b/token.h
@@ -34,6 +34,7 @@
 // (Normally) non-printable tokens
 #define COLON           ':'                    // : (grumble: GNUmacs hates ':')
 #define CONST           'a'                    // CONST <value>
+#define FCONST          'r'                    // Floating CONST <value>
 #define ACONST          'A'                    // ACONST <value> <attrib>
 #define STRING          'b'                    // STRING <address>
 #define STRINGA8        'S'                    // Atari 800 internal STRING <address>
 #define MULTX           64                     // Multiple-character tokens
 #define DOT             128                    // [bwlsBWSL] for what follows a '.'
 
+// Macro to check for specific optimizations or override
+#define CHECK_OPTS(x)  (optim_flags[x] && !optimizeOff)
+
 // Conditional assembly structures
 IFENT {
        IFENT * if_prev;                // Ptr prev .if state block (or NULL)
        WORD if_state;                  // 0:enabled, 1:disabled
 };
 
// Pointer to IFILE or IMACRO
 IUNION {
        IFILE * ifile;
        IMACRO * imacro;
@@ -99,12 +103,12 @@ IUNION {
 
 // Ptr to IFILEs, IMACROs, and so on; back-ptr to previous input objects
 INOBJ {
-       WORD in_type;                   // 0=IFILE, 1=IMACRO ...
+       WORD in_type;                   // 0=IFILE, 1=IMACRO, 2=IREPT
        IFENT * in_ifent;               // Pointer to .if context on entry
        INOBJ * in_link;                // Pointer to previous INOBJ
        TOKEN * in_otok;                // Old `tok' value
        TOKEN * in_etok;                // Old `etok' value
-       IUNION inobj;                   // IFILE or IMACRO ...
+       IUNION inobj;                   // IFILE or IMACRO or IREPT
 };
 
 // Information about a file
@@ -128,21 +132,20 @@ TOKENSTREAM {
 // Information about a macro invocation
 IMACRO {
        IMACRO * im_link;               // Pointer to ancient IMACROs
-       struct LineList * im_nextln;    // Next line to include
+       LLIST * im_nextln;              // Next line to include
        WORD im_nargs;                  // # of arguments supplied on invocation
        WORD im_siz;                    // Size suffix supplied on invocation
        LONG im_olduniq;                // Old value of 'macuniq'
        SYM * im_macro;                 // Pointer to macro we're in
        char im_lnbuf[LNSIZ];   // Line buffer
-       uint32_t argBase;               // Base in argPtrs[] for current macro
        TOKENSTREAM argument[20];       // Assume no more than 20 arguments in an invocation
 };
 
 // Information about a .rept invocation
 IREPT {
-       LONG * ir_firstln;              // Pointer to first line
-       LONG * ir_nextln;               // Pointer to next line
-       VALUE ir_count;                 // Repeat count (decrements)
+       LLIST * ir_firstln;             // Pointer to first line
+       LLIST * ir_nextln;              // Pointer to next line
+       uint32_t ir_count;              // Repeat count (decrements)
 };
 
 // Exported variables
@@ -157,6 +160,7 @@ extern char tolowertab[];
 extern INOBJ * cur_inobj;
 extern int mjump_align;
 extern char * string[];
+int optimizeOff;
 
 // Exported functions
 int include(int, char *);
@@ -34,6 +34,7 @@
 };
 
-// Pointer to IFILE or IMACRO
+// Pointer to IFILE or IMACRO or IREPT
 IUNION {
        IFILE * ifile;